@@ -1,5 +1,10 @@
-import os
-from django.contrib.gis.utils import GeoIP
+try:
+    from django.contrib.gis.geoip import GeoIP
+except ImportError:
+    from django.contrib.gis.utils import GeoIP
+
+from .utils import get_ip_of_request
+from .settings import CACHE_METHOD
 
 def get_country(request):
     ip = get_ip_of_request(request)
@@ -7,8 +12,8 @@ def get_country(request):
         g = GeoIP(cache=CACHE_METHOD)
         return g.country(ip)
     return None
-    
-    
+
+
 def get_city(request):
     ip = get_ip_of_request(request)
     if ip:
@@ -23,28 +28,19 @@ def get_lat_lon(request):
         g = GeoIP(cache=CACHE_METHOD)
         return g.lat_lon(ip)
     return None
-    
-    
+
+
 def get_country_code(request):
     ip = get_ip_of_request(request)
     if ip:
         g = GeoIP(cache=CACHE_METHOD)
         return g.country_code(ip)
     return None
-    
-    
+
+
 def get_country_name(request):
     ip = get_ip_of_request(request)
     if ip:
         g = GeoIP(cache=CACHE_METHOD)
         return g.country_name(ip)
     return None
-    
-
-def where():
-    f = os.path.split(__file__)[0]
-    return os.path.abspath(os.path.join(f, 'data'))
-    
-    
-if __name__ == '__main__':
-    print where()
\ No newline at end of file
